# coding: utf-8

"""
TelephonyApi.py
Copyright 2016 SmartBear Software

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
"""

from __future__ import absolute_import

import sys
import os
import re

# python 2 and python 3 compatibility library
from six import iteritems

from ..configuration import Configuration
from ..api_client import ApiClient


class TelephonyApi(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        config = Configuration()
        if api_client:
            self.api_client = api_client
        else:
            if not config.api_client:
                config.api_client = ApiClient()
            self.api_client = config.api_client

    def get_telephony_siptraces(self, date_start, date_end, **kwargs):
        """
        Fetch SIP metadata
        Fetch SIP metadata that matches a given parameter. If exactMatch is passed as a parameter only sip records that have exactly that value will be returned. For example, some records contain conversationId but not all relevant records for that call may contain the conversationId so only a partial view of the call will be reflected

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_telephony_siptraces(date_start, date_end, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param datetime date_start: Start date of the search. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z (required)
        :param datetime date_end: End date of the search. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z (required)
        :param str call_id: unique identification of the placed call
        :param str to_user: User to who the call was placed
        :param str from_user: user who placed the call
        :param str conversation_id: Unique identification of the conversation
        :return: SipSearchResult
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['date_start', 'date_end', 'call_id', 'to_user', 'from_user', 'conversation_id']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_telephony_siptraces" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'date_start' is set
        if ('date_start' not in params) or (params['date_start'] is None):
            raise ValueError("Missing the required parameter `date_start` when calling `get_telephony_siptraces`")
        # verify the required parameter 'date_end' is set
        if ('date_end' not in params) or (params['date_end'] is None):
            raise ValueError("Missing the required parameter `date_end` when calling `get_telephony_siptraces`")


        resource_path = '/api/v2/telephony/siptraces'.replace('{format}', 'json')
        path_params = {}

        query_params = {}
        if 'call_id' in params:
            query_params['callId'] = params['call_id']
        if 'to_user' in params:
            query_params['toUser'] = params['to_user']
        if 'from_user' in params:
            query_params['fromUser'] = params['from_user']
        if 'conversation_id' in params:
            query_params['conversationId'] = params['conversation_id']
        if 'date_start' in params:
            query_params['dateStart'] = params['date_start']
        if 'date_end' in params:
            query_params['dateEnd'] = params['date_end']

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud OAuth']

        response = self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='SipSearchResult',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def get_telephony_siptraces_download_download_id(self, download_id, **kwargs):
        """
        Get signed S3 URL for a pcap download
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_telephony_siptraces_download_download_id(download_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str download_id: unique id for the downloaded file in S3 (required)
        :return: SignedUrlResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['download_id']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_telephony_siptraces_download_download_id" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'download_id' is set
        if ('download_id' not in params) or (params['download_id'] is None):
            raise ValueError("Missing the required parameter `download_id` when calling `get_telephony_siptraces_download_download_id`")


        resource_path = '/api/v2/telephony/siptraces/download/{downloadId}'.replace('{format}', 'json')
        path_params = {}
        if 'download_id' in params:
            path_params['downloadId'] = params['download_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud OAuth']

        response = self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='SignedUrlResponse',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def post_telephony_siptraces_download(self, sip_search_public_request, **kwargs):
        """
        Request a download of a pcap file to S3
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.post_telephony_siptraces_download(sip_search_public_request, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param SIPSearchPublicRequest sip_search_public_request:  (required)
        :return: SipDownloadResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['sip_search_public_request']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_telephony_siptraces_download" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'sip_search_public_request' is set
        if ('sip_search_public_request' not in params) or (params['sip_search_public_request'] is None):
            raise ValueError("Missing the required parameter `sip_search_public_request` when calling `post_telephony_siptraces_download`")


        resource_path = '/api/v2/telephony/siptraces/download'.replace('{format}', 'json')
        path_params = {}

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'sip_search_public_request' in params:
            body_params = params['sip_search_public_request']

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud OAuth']

        response = self.api_client.call_api(resource_path, 'POST',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='SipDownloadResponse',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response



# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class SchedulingStatusResponse(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        SchedulingStatusResponse - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'status': 'str',
            'error_details': 'list[SchedulingProcessingError]',
            'scheduling_result_uri': 'str',
            'percent_complete': 'int'
        }

        self.attribute_map = {
            'id': 'id',
            'status': 'status',
            'error_details': 'errorDetails',
            'scheduling_result_uri': 'schedulingResultUri',
            'percent_complete': 'percentComplete'
        }

        self._id = None
        self._status = None
        self._error_details = None
        self._scheduling_result_uri = None
        self._percent_complete = None

    @property
    def id(self):
        """
        Gets the id of this SchedulingStatusResponse.
        The ID generated for the scheduling job.  Use to GET result when job is completed.

        :return: The id of this SchedulingStatusResponse.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this SchedulingStatusResponse.
        The ID generated for the scheduling job.  Use to GET result when job is completed.

        :param id: The id of this SchedulingStatusResponse.
        :type: str
        """
        
        self._id = id

    @property
    def status(self):
        """
        Gets the status of this SchedulingStatusResponse.
        The status of the scheduling job.

        :return: The status of this SchedulingStatusResponse.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this SchedulingStatusResponse.
        The status of the scheduling job.

        :param status: The status of this SchedulingStatusResponse.
        :type: str
        """
        allowed_values = ["Pending", "Success", "Failed", "Ongoing", "PartialFailure"]
        if status.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for status -> " + status)
            self._status = "outdated_sdk_version"
        else:
            self._status = status

    @property
    def error_details(self):
        """
        Gets the error_details of this SchedulingStatusResponse.
        If the request could not be properly processed, error details will be given here.

        :return: The error_details of this SchedulingStatusResponse.
        :rtype: list[SchedulingProcessingError]
        """
        return self._error_details

    @error_details.setter
    def error_details(self, error_details):
        """
        Sets the error_details of this SchedulingStatusResponse.
        If the request could not be properly processed, error details will be given here.

        :param error_details: The error_details of this SchedulingStatusResponse.
        :type: list[SchedulingProcessingError]
        """
        
        self._error_details = error_details

    @property
    def scheduling_result_uri(self):
        """
        Gets the scheduling_result_uri of this SchedulingStatusResponse.
        The uri of the scheduling result. It has a value if the status is 'Success'.

        :return: The scheduling_result_uri of this SchedulingStatusResponse.
        :rtype: str
        """
        return self._scheduling_result_uri

    @scheduling_result_uri.setter
    def scheduling_result_uri(self, scheduling_result_uri):
        """
        Sets the scheduling_result_uri of this SchedulingStatusResponse.
        The uri of the scheduling result. It has a value if the status is 'Success'.

        :param scheduling_result_uri: The scheduling_result_uri of this SchedulingStatusResponse.
        :type: str
        """
        
        self._scheduling_result_uri = scheduling_result_uri

    @property
    def percent_complete(self):
        """
        Gets the percent_complete of this SchedulingStatusResponse.
        The percentage of the job that is complete.

        :return: The percent_complete of this SchedulingStatusResponse.
        :rtype: int
        """
        return self._percent_complete

    @percent_complete.setter
    def percent_complete(self, percent_complete):
        """
        Sets the percent_complete of this SchedulingStatusResponse.
        The percentage of the job that is complete.

        :param percent_complete: The percent_complete of this SchedulingStatusResponse.
        :type: int
        """
        
        self._percent_complete = percent_complete

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class IntegrationStatusInfo(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        IntegrationStatusInfo - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'code': 'str',
            'effective': 'str',
            'detail': 'MessageInfo',
            'last_updated': 'datetime'
        }

        self.attribute_map = {
            'code': 'code',
            'effective': 'effective',
            'detail': 'detail',
            'last_updated': 'lastUpdated'
        }

        self._code = None
        self._effective = None
        self._detail = None
        self._last_updated = None

    @property
    def code(self):
        """
        Gets the code of this IntegrationStatusInfo.
        Machine-readable status as reported by the integration.

        :return: The code of this IntegrationStatusInfo.
        :rtype: str
        """
        return self._code

    @code.setter
    def code(self, code):
        """
        Sets the code of this IntegrationStatusInfo.
        Machine-readable status as reported by the integration.

        :param code: The code of this IntegrationStatusInfo.
        :type: str
        """
        allowed_values = ["ACTIVE", "ACTIVATING", "INACTIVE", "DEACTIVATING", "ERROR"]
        if code.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for code -> " + code)
            self._code = "outdated_sdk_version"
        else:
            self._code = code

    @property
    def effective(self):
        """
        Gets the effective of this IntegrationStatusInfo.
        Localized, human-readable, effective status of the integration.

        :return: The effective of this IntegrationStatusInfo.
        :rtype: str
        """
        return self._effective

    @effective.setter
    def effective(self, effective):
        """
        Sets the effective of this IntegrationStatusInfo.
        Localized, human-readable, effective status of the integration.

        :param effective: The effective of this IntegrationStatusInfo.
        :type: str
        """
        
        self._effective = effective

    @property
    def detail(self):
        """
        Gets the detail of this IntegrationStatusInfo.
        Localizable status details for the integration.

        :return: The detail of this IntegrationStatusInfo.
        :rtype: MessageInfo
        """
        return self._detail

    @detail.setter
    def detail(self, detail):
        """
        Sets the detail of this IntegrationStatusInfo.
        Localizable status details for the integration.

        :param detail: The detail of this IntegrationStatusInfo.
        :type: MessageInfo
        """
        
        self._detail = detail

    @property
    def last_updated(self):
        """
        Gets the last_updated of this IntegrationStatusInfo.
        Date and time (in UTC) when the integration status (i.e. the code field) was last updated. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The last_updated of this IntegrationStatusInfo.
        :rtype: datetime
        """
        return self._last_updated

    @last_updated.setter
    def last_updated(self, last_updated):
        """
        Sets the last_updated of this IntegrationStatusInfo.
        Date and time (in UTC) when the integration status (i.e. the code field) was last updated. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param last_updated: The last_updated of this IntegrationStatusInfo.
        :type: datetime
        """
        
        self._last_updated = last_updated

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class WfmBuIntradayDataUpdateTopicBuIntradayResult(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        WfmBuIntradayDataUpdateTopicBuIntradayResult - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'start_date': 'datetime',
            'end_date': 'datetime',
            'interval_length_minutes': 'int',
            'intraday_data_groupings': 'list[WfmBuIntradayDataUpdateTopicBuIntradayDataGroup]',
            'categories': 'list[str]',
            'no_data_reason': 'str',
            'schedule': 'WfmBuIntradayDataUpdateTopicBuScheduleReference',
            'short_term_forecast': 'WfmBuIntradayDataUpdateTopicBuShortTermForecastReference'
        }

        self.attribute_map = {
            'start_date': 'startDate',
            'end_date': 'endDate',
            'interval_length_minutes': 'intervalLengthMinutes',
            'intraday_data_groupings': 'intradayDataGroupings',
            'categories': 'categories',
            'no_data_reason': 'noDataReason',
            'schedule': 'schedule',
            'short_term_forecast': 'shortTermForecast'
        }

        self._start_date = None
        self._end_date = None
        self._interval_length_minutes = None
        self._intraday_data_groupings = None
        self._categories = None
        self._no_data_reason = None
        self._schedule = None
        self._short_term_forecast = None

    @property
    def start_date(self):
        """
        Gets the start_date of this WfmBuIntradayDataUpdateTopicBuIntradayResult.


        :return: The start_date of this WfmBuIntradayDataUpdateTopicBuIntradayResult.
        :rtype: datetime
        """
        return self._start_date

    @start_date.setter
    def start_date(self, start_date):
        """
        Sets the start_date of this WfmBuIntradayDataUpdateTopicBuIntradayResult.


        :param start_date: The start_date of this WfmBuIntradayDataUpdateTopicBuIntradayResult.
        :type: datetime
        """
        
        self._start_date = start_date

    @property
    def end_date(self):
        """
        Gets the end_date of this WfmBuIntradayDataUpdateTopicBuIntradayResult.


        :return: The end_date of this WfmBuIntradayDataUpdateTopicBuIntradayResult.
        :rtype: datetime
        """
        return self._end_date

    @end_date.setter
    def end_date(self, end_date):
        """
        Sets the end_date of this WfmBuIntradayDataUpdateTopicBuIntradayResult.


        :param end_date: The end_date of this WfmBuIntradayDataUpdateTopicBuIntradayResult.
        :type: datetime
        """
        
        self._end_date = end_date

    @property
    def interval_length_minutes(self):
        """
        Gets the interval_length_minutes of this WfmBuIntradayDataUpdateTopicBuIntradayResult.


        :return: The interval_length_minutes of this WfmBuIntradayDataUpdateTopicBuIntradayResult.
        :rtype: int
        """
        return self._interval_length_minutes

    @interval_length_minutes.setter
    def interval_length_minutes(self, interval_length_minutes):
        """
        Sets the interval_length_minutes of this WfmBuIntradayDataUpdateTopicBuIntradayResult.


        :param interval_length_minutes: The interval_length_minutes of this WfmBuIntradayDataUpdateTopicBuIntradayResult.
        :type: int
        """
        
        self._interval_length_minutes = interval_length_minutes

    @property
    def intraday_data_groupings(self):
        """
        Gets the intraday_data_groupings of this WfmBuIntradayDataUpdateTopicBuIntradayResult.


        :return: The intraday_data_groupings of this WfmBuIntradayDataUpdateTopicBuIntradayResult.
        :rtype: list[WfmBuIntradayDataUpdateTopicBuIntradayDataGroup]
        """
        return self._intraday_data_groupings

    @intraday_data_groupings.setter
    def intraday_data_groupings(self, intraday_data_groupings):
        """
        Sets the intraday_data_groupings of this WfmBuIntradayDataUpdateTopicBuIntradayResult.


        :param intraday_data_groupings: The intraday_data_groupings of this WfmBuIntradayDataUpdateTopicBuIntradayResult.
        :type: list[WfmBuIntradayDataUpdateTopicBuIntradayDataGroup]
        """
        
        self._intraday_data_groupings = intraday_data_groupings

    @property
    def categories(self):
        """
        Gets the categories of this WfmBuIntradayDataUpdateTopicBuIntradayResult.


        :return: The categories of this WfmBuIntradayDataUpdateTopicBuIntradayResult.
        :rtype: list[str]
        """
        return self._categories

    @categories.setter
    def categories(self, categories):
        """
        Sets the categories of this WfmBuIntradayDataUpdateTopicBuIntradayResult.


        :param categories: The categories of this WfmBuIntradayDataUpdateTopicBuIntradayResult.
        :type: list[str]
        """
        
        self._categories = categories

    @property
    def no_data_reason(self):
        """
        Gets the no_data_reason of this WfmBuIntradayDataUpdateTopicBuIntradayResult.


        :return: The no_data_reason of this WfmBuIntradayDataUpdateTopicBuIntradayResult.
        :rtype: str
        """
        return self._no_data_reason

    @no_data_reason.setter
    def no_data_reason(self, no_data_reason):
        """
        Sets the no_data_reason of this WfmBuIntradayDataUpdateTopicBuIntradayResult.


        :param no_data_reason: The no_data_reason of this WfmBuIntradayDataUpdateTopicBuIntradayResult.
        :type: str
        """
        
        self._no_data_reason = no_data_reason

    @property
    def schedule(self):
        """
        Gets the schedule of this WfmBuIntradayDataUpdateTopicBuIntradayResult.


        :return: The schedule of this WfmBuIntradayDataUpdateTopicBuIntradayResult.
        :rtype: WfmBuIntradayDataUpdateTopicBuScheduleReference
        """
        return self._schedule

    @schedule.setter
    def schedule(self, schedule):
        """
        Sets the schedule of this WfmBuIntradayDataUpdateTopicBuIntradayResult.


        :param schedule: The schedule of this WfmBuIntradayDataUpdateTopicBuIntradayResult.
        :type: WfmBuIntradayDataUpdateTopicBuScheduleReference
        """
        
        self._schedule = schedule

    @property
    def short_term_forecast(self):
        """
        Gets the short_term_forecast of this WfmBuIntradayDataUpdateTopicBuIntradayResult.


        :return: The short_term_forecast of this WfmBuIntradayDataUpdateTopicBuIntradayResult.
        :rtype: WfmBuIntradayDataUpdateTopicBuShortTermForecastReference
        """
        return self._short_term_forecast

    @short_term_forecast.setter
    def short_term_forecast(self, short_term_forecast):
        """
        Sets the short_term_forecast of this WfmBuIntradayDataUpdateTopicBuIntradayResult.


        :param short_term_forecast: The short_term_forecast of this WfmBuIntradayDataUpdateTopicBuIntradayResult.
        :type: WfmBuIntradayDataUpdateTopicBuShortTermForecastReference
        """
        
        self._short_term_forecast = short_term_forecast

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class WebChatMessage(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        WebChatMessage - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'conversation': 'WebChatConversation',
            'sender': 'WebChatMemberInfo',
            'body': 'str',
            'body_type': 'str',
            'timestamp': 'datetime',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'conversation': 'conversation',
            'sender': 'sender',
            'body': 'body',
            'body_type': 'bodyType',
            'timestamp': 'timestamp',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._conversation = None
        self._sender = None
        self._body = None
        self._body_type = None
        self._timestamp = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this WebChatMessage.
        The globally unique identifier for the object.

        :return: The id of this WebChatMessage.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this WebChatMessage.
        The globally unique identifier for the object.

        :param id: The id of this WebChatMessage.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this WebChatMessage.


        :return: The name of this WebChatMessage.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this WebChatMessage.


        :param name: The name of this WebChatMessage.
        :type: str
        """
        
        self._name = name

    @property
    def conversation(self):
        """
        Gets the conversation of this WebChatMessage.
        The identifier of the conversation

        :return: The conversation of this WebChatMessage.
        :rtype: WebChatConversation
        """
        return self._conversation

    @conversation.setter
    def conversation(self, conversation):
        """
        Sets the conversation of this WebChatMessage.
        The identifier of the conversation

        :param conversation: The conversation of this WebChatMessage.
        :type: WebChatConversation
        """
        
        self._conversation = conversation

    @property
    def sender(self):
        """
        Gets the sender of this WebChatMessage.
        The member who sent the message

        :return: The sender of this WebChatMessage.
        :rtype: WebChatMemberInfo
        """
        return self._sender

    @sender.setter
    def sender(self, sender):
        """
        Sets the sender of this WebChatMessage.
        The member who sent the message

        :param sender: The sender of this WebChatMessage.
        :type: WebChatMemberInfo
        """
        
        self._sender = sender

    @property
    def body(self):
        """
        Gets the body of this WebChatMessage.
        The message body.

        :return: The body of this WebChatMessage.
        :rtype: str
        """
        return self._body

    @body.setter
    def body(self, body):
        """
        Sets the body of this WebChatMessage.
        The message body.

        :param body: The body of this WebChatMessage.
        :type: str
        """
        
        self._body = body

    @property
    def body_type(self):
        """
        Gets the body_type of this WebChatMessage.
        The purpose of the message within the conversation, such as a standard text entry versus a greeting.

        :return: The body_type of this WebChatMessage.
        :rtype: str
        """
        return self._body_type

    @body_type.setter
    def body_type(self, body_type):
        """
        Sets the body_type of this WebChatMessage.
        The purpose of the message within the conversation, such as a standard text entry versus a greeting.

        :param body_type: The body_type of this WebChatMessage.
        :type: str
        """
        allowed_values = ["standard", "notice", "member-join", "member-leave", "media-request"]
        if body_type.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for body_type -> " + body_type)
            self._body_type = "outdated_sdk_version"
        else:
            self._body_type = body_type

    @property
    def timestamp(self):
        """
        Gets the timestamp of this WebChatMessage.
        The timestamp of the message, in ISO-8601 format

        :return: The timestamp of this WebChatMessage.
        :rtype: datetime
        """
        return self._timestamp

    @timestamp.setter
    def timestamp(self, timestamp):
        """
        Sets the timestamp of this WebChatMessage.
        The timestamp of the message, in ISO-8601 format

        :param timestamp: The timestamp of this WebChatMessage.
        :type: datetime
        """
        
        self._timestamp = timestamp

    @property
    def self_uri(self):
        """
        Gets the self_uri of this WebChatMessage.
        The URI for this object

        :return: The self_uri of this WebChatMessage.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this WebChatMessage.
        The URI for this object

        :param self_uri: The self_uri of this WebChatMessage.
        :type: str
        """
        
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class SystemMessageSystemMessage(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        SystemMessageSystemMessage - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'channel_id': 'str',
            'system_topic_type': 'str',
            'correlation_id': 'str',
            'organization_id': 'str',
            'user_id': 'str',
            'oauth_client_id': 'str',
            'reason': 'str',
            'message': 'str',
            'data': 'object'
        }

        self.attribute_map = {
            'channel_id': 'channelId',
            'system_topic_type': 'systemTopicType',
            'correlation_id': 'correlationId',
            'organization_id': 'organizationId',
            'user_id': 'userId',
            'oauth_client_id': 'oauthClientId',
            'reason': 'reason',
            'message': 'message',
            'data': 'data'
        }

        self._channel_id = None
        self._system_topic_type = None
        self._correlation_id = None
        self._organization_id = None
        self._user_id = None
        self._oauth_client_id = None
        self._reason = None
        self._message = None
        self._data = None

    @property
    def channel_id(self):
        """
        Gets the channel_id of this SystemMessageSystemMessage.


        :return: The channel_id of this SystemMessageSystemMessage.
        :rtype: str
        """
        return self._channel_id

    @channel_id.setter
    def channel_id(self, channel_id):
        """
        Sets the channel_id of this SystemMessageSystemMessage.


        :param channel_id: The channel_id of this SystemMessageSystemMessage.
        :type: str
        """
        
        self._channel_id = channel_id

    @property
    def system_topic_type(self):
        """
        Gets the system_topic_type of this SystemMessageSystemMessage.


        :return: The system_topic_type of this SystemMessageSystemMessage.
        :rtype: str
        """
        return self._system_topic_type

    @system_topic_type.setter
    def system_topic_type(self, system_topic_type):
        """
        Sets the system_topic_type of this SystemMessageSystemMessage.


        :param system_topic_type: The system_topic_type of this SystemMessageSystemMessage.
        :type: str
        """
        allowed_values = ["no_longer_subscribed", "subscription_changed", "token_revoked"]
        if system_topic_type.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for system_topic_type -> " + system_topic_type)
            self._system_topic_type = "outdated_sdk_version"
        else:
            self._system_topic_type = system_topic_type

    @property
    def correlation_id(self):
        """
        Gets the correlation_id of this SystemMessageSystemMessage.


        :return: The correlation_id of this SystemMessageSystemMessage.
        :rtype: str
        """
        return self._correlation_id

    @correlation_id.setter
    def correlation_id(self, correlation_id):
        """
        Sets the correlation_id of this SystemMessageSystemMessage.


        :param correlation_id: The correlation_id of this SystemMessageSystemMessage.
        :type: str
        """
        
        self._correlation_id = correlation_id

    @property
    def organization_id(self):
        """
        Gets the organization_id of this SystemMessageSystemMessage.


        :return: The organization_id of this SystemMessageSystemMessage.
        :rtype: str
        """
        return self._organization_id

    @organization_id.setter
    def organization_id(self, organization_id):
        """
        Sets the organization_id of this SystemMessageSystemMessage.


        :param organization_id: The organization_id of this SystemMessageSystemMessage.
        :type: str
        """
        
        self._organization_id = organization_id

    @property
    def user_id(self):
        """
        Gets the user_id of this SystemMessageSystemMessage.


        :return: The user_id of this SystemMessageSystemMessage.
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """
        Sets the user_id of this SystemMessageSystemMessage.


        :param user_id: The user_id of this SystemMessageSystemMessage.
        :type: str
        """
        
        self._user_id = user_id

    @property
    def oauth_client_id(self):
        """
        Gets the oauth_client_id of this SystemMessageSystemMessage.


        :return: The oauth_client_id of this SystemMessageSystemMessage.
        :rtype: str
        """
        return self._oauth_client_id

    @oauth_client_id.setter
    def oauth_client_id(self, oauth_client_id):
        """
        Sets the oauth_client_id of this SystemMessageSystemMessage.


        :param oauth_client_id: The oauth_client_id of this SystemMessageSystemMessage.
        :type: str
        """
        
        self._oauth_client_id = oauth_client_id

    @property
    def reason(self):
        """
        Gets the reason of this SystemMessageSystemMessage.


        :return: The reason of this SystemMessageSystemMessage.
        :rtype: str
        """
        return self._reason

    @reason.setter
    def reason(self, reason):
        """
        Sets the reason of this SystemMessageSystemMessage.


        :param reason: The reason of this SystemMessageSystemMessage.
        :type: str
        """
        allowed_values = ["another_channel_subscribed", "user_tokens_revoked"]
        if reason.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for reason -> " + reason)
            self._reason = "outdated_sdk_version"
        else:
            self._reason = reason

    @property
    def message(self):
        """
        Gets the message of this SystemMessageSystemMessage.


        :return: The message of this SystemMessageSystemMessage.
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """
        Sets the message of this SystemMessageSystemMessage.


        :param message: The message of this SystemMessageSystemMessage.
        :type: str
        """
        
        self._message = message

    @property
    def data(self):
        """
        Gets the data of this SystemMessageSystemMessage.


        :return: The data of this SystemMessageSystemMessage.
        :rtype: object
        """
        return self._data

    @data.setter
    def data(self, data):
        """
        Sets the data of this SystemMessageSystemMessage.


        :param data: The data of this SystemMessageSystemMessage.
        :type: object
        """
        
        self._data = data

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class ScimV2User(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        ScimV2User - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'schemas': 'list[str]',
            'active': 'bool',
            'user_name': 'str',
            'display_name': 'str',
            'password': 'str',
            'title': 'str',
            'phone_numbers': 'list[ScimPhoneNumber]',
            'emails': 'list[ScimEmail]',
            'external_id': 'str',
            'groups': 'list[ScimV2GroupReference]',
            'roles': 'list[ScimUserRole]',
            'urnietfparamsscimschemasextensionenterprise2_0_user': 'ScimV2EnterpriseUser',
            'urnietfparamsscimschemasextensiongenesyspurecloud2_0_user': 'ScimUserExtensions',
            'meta': 'ScimMetadata'
        }

        self.attribute_map = {
            'id': 'id',
            'schemas': 'schemas',
            'active': 'active',
            'user_name': 'userName',
            'display_name': 'displayName',
            'password': 'password',
            'title': 'title',
            'phone_numbers': 'phoneNumbers',
            'emails': 'emails',
            'external_id': 'externalId',
            'groups': 'groups',
            'roles': 'roles',
            'urnietfparamsscimschemasextensionenterprise2_0_user': 'urn:ietf:params:scim:schemas:extension:enterprise:2.0:User',
            'urnietfparamsscimschemasextensiongenesyspurecloud2_0_user': 'urn:ietf:params:scim:schemas:extension:genesys:purecloud:2.0:User',
            'meta': 'meta'
        }

        self._id = None
        self._schemas = None
        self._active = None
        self._user_name = None
        self._display_name = None
        self._password = None
        self._title = None
        self._phone_numbers = None
        self._emails = None
        self._external_id = None
        self._groups = None
        self._roles = None
        self._urnietfparamsscimschemasextensionenterprise2_0_user = None
        self._urnietfparamsscimschemasextensiongenesyspurecloud2_0_user = None
        self._meta = None

    @property
    def id(self):
        """
        Gets the id of this ScimV2User.
        The ID of the SCIM resource. Set by the service provider. \"caseExact\" is set to \"true\". \"mutability\" is set to \"readOnly\". \"returned\" is set to \"always\".

        :return: The id of this ScimV2User.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this ScimV2User.
        The ID of the SCIM resource. Set by the service provider. \"caseExact\" is set to \"true\". \"mutability\" is set to \"readOnly\". \"returned\" is set to \"always\".

        :param id: The id of this ScimV2User.
        :type: str
        """
        
        self._id = id

    @property
    def schemas(self):
        """
        Gets the schemas of this ScimV2User.
        The list of supported schemas.

        :return: The schemas of this ScimV2User.
        :rtype: list[str]
        """
        return self._schemas

    @schemas.setter
    def schemas(self, schemas):
        """
        Sets the schemas of this ScimV2User.
        The list of supported schemas.

        :param schemas: The schemas of this ScimV2User.
        :type: list[str]
        """
        
        self._schemas = schemas

    @property
    def active(self):
        """
        Gets the active of this ScimV2User.
        Indicates whether the user's administrative status is active.

        :return: The active of this ScimV2User.
        :rtype: bool
        """
        return self._active

    @active.setter
    def active(self, active):
        """
        Sets the active of this ScimV2User.
        Indicates whether the user's administrative status is active.

        :param active: The active of this ScimV2User.
        :type: bool
        """
        
        self._active = active

    @property
    def user_name(self):
        """
        Gets the user_name of this ScimV2User.
        The user's Genesys Cloud email address. Must be unique.

        :return: The user_name of this ScimV2User.
        :rtype: str
        """
        return self._user_name

    @user_name.setter
    def user_name(self, user_name):
        """
        Sets the user_name of this ScimV2User.
        The user's Genesys Cloud email address. Must be unique.

        :param user_name: The user_name of this ScimV2User.
        :type: str
        """
        
        self._user_name = user_name

    @property
    def display_name(self):
        """
        Gets the display_name of this ScimV2User.
        The display name of the user.

        :return: The display_name of this ScimV2User.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this ScimV2User.
        The display name of the user.

        :param display_name: The display_name of this ScimV2User.
        :type: str
        """
        
        self._display_name = display_name

    @property
    def password(self):
        """
        Gets the password of this ScimV2User.
        The new password for the Genesys Cloud user. Does not return an existing password. When creating a user, if a password is not supplied, then a password will be randomly generated that is 40 characters in length and contains five characters from each of the password policy groups.

        :return: The password of this ScimV2User.
        :rtype: str
        """
        return self._password

    @password.setter
    def password(self, password):
        """
        Sets the password of this ScimV2User.
        The new password for the Genesys Cloud user. Does not return an existing password. When creating a user, if a password is not supplied, then a password will be randomly generated that is 40 characters in length and contains five characters from each of the password policy groups.

        :param password: The password of this ScimV2User.
        :type: str
        """
        
        self._password = password

    @property
    def title(self):
        """
        Gets the title of this ScimV2User.
        The user's title.

        :return: The title of this ScimV2User.
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """
        Sets the title of this ScimV2User.
        The user's title.

        :param title: The title of this ScimV2User.
        :type: str
        """
        
        self._title = title

    @property
    def phone_numbers(self):
        """
        Gets the phone_numbers of this ScimV2User.
        The list of the user's phone numbers.

        :return: The phone_numbers of this ScimV2User.
        :rtype: list[ScimPhoneNumber]
        """
        return self._phone_numbers

    @phone_numbers.setter
    def phone_numbers(self, phone_numbers):
        """
        Sets the phone_numbers of this ScimV2User.
        The list of the user's phone numbers.

        :param phone_numbers: The phone_numbers of this ScimV2User.
        :type: list[ScimPhoneNumber]
        """
        
        self._phone_numbers = phone_numbers

    @property
    def emails(self):
        """
        Gets the emails of this ScimV2User.
        The list of the user's email addresses.

        :return: The emails of this ScimV2User.
        :rtype: list[ScimEmail]
        """
        return self._emails

    @emails.setter
    def emails(self, emails):
        """
        Sets the emails of this ScimV2User.
        The list of the user's email addresses.

        :param emails: The emails of this ScimV2User.
        :type: list[ScimEmail]
        """
        
        self._emails = emails

    @property
    def external_id(self):
        """
        Gets the external_id of this ScimV2User.
        The external ID of the user. Set by the provisioning client. \"caseExact\" is set to \"true\". \"mutability\" is set to \"readWrite\".

        :return: The external_id of this ScimV2User.
        :rtype: str
        """
        return self._external_id

    @external_id.setter
    def external_id(self, external_id):
        """
        Sets the external_id of this ScimV2User.
        The external ID of the user. Set by the provisioning client. \"caseExact\" is set to \"true\". \"mutability\" is set to \"readWrite\".

        :param external_id: The external_id of this ScimV2User.
        :type: str
        """
        
        self._external_id = external_id

    @property
    def groups(self):
        """
        Gets the groups of this ScimV2User.
        The list of groups that the user is a member of.

        :return: The groups of this ScimV2User.
        :rtype: list[ScimV2GroupReference]
        """
        return self._groups

    @groups.setter
    def groups(self, groups):
        """
        Sets the groups of this ScimV2User.
        The list of groups that the user is a member of.

        :param groups: The groups of this ScimV2User.
        :type: list[ScimV2GroupReference]
        """
        
        self._groups = groups

    @property
    def roles(self):
        """
        Gets the roles of this ScimV2User.
        The list of roles assigned to the user.

        :return: The roles of this ScimV2User.
        :rtype: list[ScimUserRole]
        """
        return self._roles

    @roles.setter
    def roles(self, roles):
        """
        Sets the roles of this ScimV2User.
        The list of roles assigned to the user.

        :param roles: The roles of this ScimV2User.
        :type: list[ScimUserRole]
        """
        
        self._roles = roles

    @property
    def urnietfparamsscimschemasextensionenterprise2_0_user(self):
        """
        Gets the urnietfparamsscimschemasextensionenterprise2_0_user of this ScimV2User.
        The URI of the schema for the enterprise user.

        :return: The urnietfparamsscimschemasextensionenterprise2_0_user of this ScimV2User.
        :rtype: ScimV2EnterpriseUser
        """
        return self._urnietfparamsscimschemasextensionenterprise2_0_user

    @urnietfparamsscimschemasextensionenterprise2_0_user.setter
    def urnietfparamsscimschemasextensionenterprise2_0_user(self, urnietfparamsscimschemasextensionenterprise2_0_user):
        """
        Sets the urnietfparamsscimschemasextensionenterprise2_0_user of this ScimV2User.
        The URI of the schema for the enterprise user.

        :param urnietfparamsscimschemasextensionenterprise2_0_user: The urnietfparamsscimschemasextensionenterprise2_0_user of this ScimV2User.
        :type: ScimV2EnterpriseUser
        """
        
        self._urnietfparamsscimschemasextensionenterprise2_0_user = urnietfparamsscimschemasextensionenterprise2_0_user

    @property
    def urnietfparamsscimschemasextensiongenesyspurecloud2_0_user(self):
        """
        Gets the urnietfparamsscimschemasextensiongenesyspurecloud2_0_user of this ScimV2User.
        The URI of the schema for the Genesys Cloud user.

        :return: The urnietfparamsscimschemasextensiongenesyspurecloud2_0_user of this ScimV2User.
        :rtype: ScimUserExtensions
        """
        return self._urnietfparamsscimschemasextensiongenesyspurecloud2_0_user

    @urnietfparamsscimschemasextensiongenesyspurecloud2_0_user.setter
    def urnietfparamsscimschemasextensiongenesyspurecloud2_0_user(self, urnietfparamsscimschemasextensiongenesyspurecloud2_0_user):
        """
        Sets the urnietfparamsscimschemasextensiongenesyspurecloud2_0_user of this ScimV2User.
        The URI of the schema for the Genesys Cloud user.

        :param urnietfparamsscimschemasextensiongenesyspurecloud2_0_user: The urnietfparamsscimschemasextensiongenesyspurecloud2_0_user of this ScimV2User.
        :type: ScimUserExtensions
        """
        
        self._urnietfparamsscimschemasextensiongenesyspurecloud2_0_user = urnietfparamsscimschemasextensiongenesyspurecloud2_0_user

    @property
    def meta(self):
        """
        Gets the meta of this ScimV2User.
        The metadata of the SCIM resource.

        :return: The meta of this ScimV2User.
        :rtype: ScimMetadata
        """
        return self._meta

    @meta.setter
    def meta(self, meta):
        """
        Sets the meta of this ScimV2User.
        The metadata of the SCIM resource.

        :param meta: The meta of this ScimV2User.
        :type: ScimMetadata
        """
        
        self._meta = meta

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class ActionTarget(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        ActionTarget - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'user_data': 'list[KeyValue]',
            'supported_media_types': 'list[str]',
            'state': 'str',
            'description': 'str',
            'service_level': 'ServiceLevel',
            'short_abandon_threshold': 'int',
            'self_uri': 'str',
            'created_date': 'datetime',
            'modified_date': 'datetime'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'user_data': 'userData',
            'supported_media_types': 'supportedMediaTypes',
            'state': 'state',
            'description': 'description',
            'service_level': 'serviceLevel',
            'short_abandon_threshold': 'shortAbandonThreshold',
            'self_uri': 'selfUri',
            'created_date': 'createdDate',
            'modified_date': 'modifiedDate'
        }

        self._id = None
        self._name = None
        self._user_data = None
        self._supported_media_types = None
        self._state = None
        self._description = None
        self._service_level = None
        self._short_abandon_threshold = None
        self._self_uri = None
        self._created_date = None
        self._modified_date = None

    @property
    def id(self):
        """
        Gets the id of this ActionTarget.
        The globally unique identifier for the object.

        :return: The id of this ActionTarget.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this ActionTarget.
        The globally unique identifier for the object.

        :param id: The id of this ActionTarget.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this ActionTarget.


        :return: The name of this ActionTarget.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this ActionTarget.


        :param name: The name of this ActionTarget.
        :type: str
        """
        
        self._name = name

    @property
    def user_data(self):
        """
        Gets the user_data of this ActionTarget.
        Additional user data associated with the target in key/value format.

        :return: The user_data of this ActionTarget.
        :rtype: list[KeyValue]
        """
        return self._user_data

    @user_data.setter
    def user_data(self, user_data):
        """
        Sets the user_data of this ActionTarget.
        Additional user data associated with the target in key/value format.

        :param user_data: The user_data of this ActionTarget.
        :type: list[KeyValue]
        """
        
        self._user_data = user_data

    @property
    def supported_media_types(self):
        """
        Gets the supported_media_types of this ActionTarget.
        Supported media types of the target.

        :return: The supported_media_types of this ActionTarget.
        :rtype: list[str]
        """
        return self._supported_media_types

    @supported_media_types.setter
    def supported_media_types(self, supported_media_types):
        """
        Sets the supported_media_types of this ActionTarget.
        Supported media types of the target.

        :param supported_media_types: The supported_media_types of this ActionTarget.
        :type: list[str]
        """
        
        self._supported_media_types = supported_media_types

    @property
    def state(self):
        """
        Gets the state of this ActionTarget.
        Indicates the state of the target.

        :return: The state of this ActionTarget.
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """
        Sets the state of this ActionTarget.
        Indicates the state of the target.

        :param state: The state of this ActionTarget.
        :type: str
        """
        allowed_values = ["active", "inactive", "deleted"]
        if state.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for state -> " + state)
            self._state = "outdated_sdk_version"
        else:
            self._state = state

    @property
    def description(self):
        """
        Gets the description of this ActionTarget.
        Description of the target.

        :return: The description of this ActionTarget.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this ActionTarget.
        Description of the target.

        :param description: The description of this ActionTarget.
        :type: str
        """
        
        self._description = description

    @property
    def service_level(self):
        """
        Gets the service_level of this ActionTarget.
        Service Level of the action target. Chat offers for the target will be throttled with the aim of achieving this service level.

        :return: The service_level of this ActionTarget.
        :rtype: ServiceLevel
        """
        return self._service_level

    @service_level.setter
    def service_level(self, service_level):
        """
        Sets the service_level of this ActionTarget.
        Service Level of the action target. Chat offers for the target will be throttled with the aim of achieving this service level.

        :param service_level: The service_level of this ActionTarget.
        :type: ServiceLevel
        """
        
        self._service_level = service_level

    @property
    def short_abandon_threshold(self):
        """
        Gets the short_abandon_threshold of this ActionTarget.
        Indicates the non-default short abandon threshold

        :return: The short_abandon_threshold of this ActionTarget.
        :rtype: int
        """
        return self._short_abandon_threshold

    @short_abandon_threshold.setter
    def short_abandon_threshold(self, short_abandon_threshold):
        """
        Sets the short_abandon_threshold of this ActionTarget.
        Indicates the non-default short abandon threshold

        :param short_abandon_threshold: The short_abandon_threshold of this ActionTarget.
        :type: int
        """
        
        self._short_abandon_threshold = short_abandon_threshold

    @property
    def self_uri(self):
        """
        Gets the self_uri of this ActionTarget.
        The URI for this object

        :return: The self_uri of this ActionTarget.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this ActionTarget.
        The URI for this object

        :param self_uri: The self_uri of this ActionTarget.
        :type: str
        """
        
        self._self_uri = self_uri

    @property
    def created_date(self):
        """
        Gets the created_date of this ActionTarget.
        The date the target was created. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The created_date of this ActionTarget.
        :rtype: datetime
        """
        return self._created_date

    @created_date.setter
    def created_date(self, created_date):
        """
        Sets the created_date of this ActionTarget.
        The date the target was created. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param created_date: The created_date of this ActionTarget.
        :type: datetime
        """
        
        self._created_date = created_date

    @property
    def modified_date(self):
        """
        Gets the modified_date of this ActionTarget.
        The date the target was last modified. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The modified_date of this ActionTarget.
        :rtype: datetime
        """
        return self._modified_date

    @modified_date.setter
    def modified_date(self, modified_date):
        """
        Sets the modified_date of this ActionTarget.
        The date the target was last modified. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param modified_date: The modified_date of this ActionTarget.
        :type: datetime
        """
        
        self._modified_date = modified_date

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class MessageMediaParticipant(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        MessageMediaParticipant - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'address': 'str',
            'start_time': 'datetime',
            'connected_time': 'datetime',
            'end_time': 'datetime',
            'start_hold_time': 'datetime',
            'purpose': 'str',
            'state': 'str',
            'direction': 'str',
            'disconnect_type': 'str',
            'held': 'bool',
            'wrapup_required': 'bool',
            'wrapup_prompt': 'str',
            'user': 'DomainEntityRef',
            'queue': 'DomainEntityRef',
            'team': 'DomainEntityRef',
            'attributes': 'dict(str, str)',
            'error_info': 'ErrorInfo',
            'script': 'DomainEntityRef',
            'wrapup_timeout_ms': 'int',
            'wrapup_skipped': 'bool',
            'alerting_timeout_ms': 'int',
            'provider': 'str',
            'external_contact': 'DomainEntityRef',
            'external_organization': 'DomainEntityRef',
            'wrapup': 'Wrapup',
            'peer': 'str',
            'flagged_reason': 'str',
            'journey_context': 'JourneyContext',
            'conversation_routing_data': 'ConversationRoutingData',
            'start_acw_time': 'datetime',
            'end_acw_time': 'datetime',
            'to_address': 'Address',
            'from_address': 'Address',
            'messages': 'list[MessageDetails]',
            'type': 'str',
            'recipient_country': 'str',
            'recipient_type': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'address': 'address',
            'start_time': 'startTime',
            'connected_time': 'connectedTime',
            'end_time': 'endTime',
            'start_hold_time': 'startHoldTime',
            'purpose': 'purpose',
            'state': 'state',
            'direction': 'direction',
            'disconnect_type': 'disconnectType',
            'held': 'held',
            'wrapup_required': 'wrapupRequired',
            'wrapup_prompt': 'wrapupPrompt',
            'user': 'user',
            'queue': 'queue',
            'team': 'team',
            'attributes': 'attributes',
            'error_info': 'errorInfo',
            'script': 'script',
            'wrapup_timeout_ms': 'wrapupTimeoutMs',
            'wrapup_skipped': 'wrapupSkipped',
            'alerting_timeout_ms': 'alertingTimeoutMs',
            'provider': 'provider',
            'external_contact': 'externalContact',
            'external_organization': 'externalOrganization',
            'wrapup': 'wrapup',
            'peer': 'peer',
            'flagged_reason': 'flaggedReason',
            'journey_context': 'journeyContext',
            'conversation_routing_data': 'conversationRoutingData',
            'start_acw_time': 'startAcwTime',
            'end_acw_time': 'endAcwTime',
            'to_address': 'toAddress',
            'from_address': 'fromAddress',
            'messages': 'messages',
            'type': 'type',
            'recipient_country': 'recipientCountry',
            'recipient_type': 'recipientType'
        }

        self._id = None
        self._name = None
        self._address = None
        self._start_time = None
        self._connected_time = None
        self._end_time = None
        self._start_hold_time = None
        self._purpose = None
        self._state = None
        self._direction = None
        self._disconnect_type = None
        self._held = None
        self._wrapup_required = None
        self._wrapup_prompt = None
        self._user = None
        self._queue = None
        self._team = None
        self._attributes = None
        self._error_info = None
        self._script = None
        self._wrapup_timeout_ms = None
        self._wrapup_skipped = None
        self._alerting_timeout_ms = None
        self._provider = None
        self._external_contact = None
        self._external_organization = None
        self._wrapup = None
        self._peer = None
        self._flagged_reason = None
        self._journey_context = None
        self._conversation_routing_data = None
        self._start_acw_time = None
        self._end_acw_time = None
        self._to_address = None
        self._from_address = None
        self._messages = None
        self._type = None
        self._recipient_country = None
        self._recipient_type = None

    @property
    def id(self):
        """
        Gets the id of this MessageMediaParticipant.
        The unique participant ID.

        :return: The id of this MessageMediaParticipant.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this MessageMediaParticipant.
        The unique participant ID.

        :param id: The id of this MessageMediaParticipant.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this MessageMediaParticipant.
        The display friendly name of the participant.

        :return: The name of this MessageMediaParticipant.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this MessageMediaParticipant.
        The display friendly name of the participant.

        :param name: The name of this MessageMediaParticipant.
        :type: str
        """
        
        self._name = name

    @property
    def address(self):
        """
        Gets the address of this MessageMediaParticipant.
        The participant address.

        :return: The address of this MessageMediaParticipant.
        :rtype: str
        """
        return self._address

    @address.setter
    def address(self, address):
        """
        Sets the address of this MessageMediaParticipant.
        The participant address.

        :param address: The address of this MessageMediaParticipant.
        :type: str
        """
        
        self._address = address

    @property
    def start_time(self):
        """
        Gets the start_time of this MessageMediaParticipant.
        The time when this participant first joined the conversation. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The start_time of this MessageMediaParticipant.
        :rtype: datetime
        """
        return self._start_time

    @start_time.setter
    def start_time(self, start_time):
        """
        Sets the start_time of this MessageMediaParticipant.
        The time when this participant first joined the conversation. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param start_time: The start_time of this MessageMediaParticipant.
        :type: datetime
        """
        
        self._start_time = start_time

    @property
    def connected_time(self):
        """
        Gets the connected_time of this MessageMediaParticipant.
        The time when this participant went connected for this media (eg: video connected time). Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The connected_time of this MessageMediaParticipant.
        :rtype: datetime
        """
        return self._connected_time

    @connected_time.setter
    def connected_time(self, connected_time):
        """
        Sets the connected_time of this MessageMediaParticipant.
        The time when this participant went connected for this media (eg: video connected time). Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param connected_time: The connected_time of this MessageMediaParticipant.
        :type: datetime
        """
        
        self._connected_time = connected_time

    @property
    def end_time(self):
        """
        Gets the end_time of this MessageMediaParticipant.
        The time when this participant went disconnected for this media (eg: video disconnected time). Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The end_time of this MessageMediaParticipant.
        :rtype: datetime
        """
        return self._end_time

    @end_time.setter
    def end_time(self, end_time):
        """
        Sets the end_time of this MessageMediaParticipant.
        The time when this participant went disconnected for this media (eg: video disconnected time). Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param end_time: The end_time of this MessageMediaParticipant.
        :type: datetime
        """
        
        self._end_time = end_time

    @property
    def start_hold_time(self):
        """
        Gets the start_hold_time of this MessageMediaParticipant.
        The time when this participant's hold started. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The start_hold_time of this MessageMediaParticipant.
        :rtype: datetime
        """
        return self._start_hold_time

    @start_hold_time.setter
    def start_hold_time(self, start_hold_time):
        """
        Sets the start_hold_time of this MessageMediaParticipant.
        The time when this participant's hold started. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param start_hold_time: The start_hold_time of this MessageMediaParticipant.
        :type: datetime
        """
        
        self._start_hold_time = start_hold_time

    @property
    def purpose(self):
        """
        Gets the purpose of this MessageMediaParticipant.
        The participant's purpose.  Values can be: 'agent', 'user', 'customer', 'external', 'acd', 'ivr

        :return: The purpose of this MessageMediaParticipant.
        :rtype: str
        """
        return self._purpose

    @purpose.setter
    def purpose(self, purpose):
        """
        Sets the purpose of this MessageMediaParticipant.
        The participant's purpose.  Values can be: 'agent', 'user', 'customer', 'external', 'acd', 'ivr

        :param purpose: The purpose of this MessageMediaParticipant.
        :type: str
        """
        
        self._purpose = purpose

    @property
    def state(self):
        """
        Gets the state of this MessageMediaParticipant.
        The participant's state.  Values can be: 'alerting', 'connected', 'disconnected', 'dialing', 'contacting

        :return: The state of this MessageMediaParticipant.
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """
        Sets the state of this MessageMediaParticipant.
        The participant's state.  Values can be: 'alerting', 'connected', 'disconnected', 'dialing', 'contacting

        :param state: The state of this MessageMediaParticipant.
        :type: str
        """
        allowed_values = ["alerting", "dialing", "contacting", "offering", "connected", "disconnected", "terminated", "converting", "uploading", "transmitting", "none"]
        if state.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for state -> " + state)
            self._state = "outdated_sdk_version"
        else:
            self._state = state

    @property
    def direction(self):
        """
        Gets the direction of this MessageMediaParticipant.
        The participant's direction.  Values can be: 'inbound' or 'outbound'

        :return: The direction of this MessageMediaParticipant.
        :rtype: str
        """
        return self._direction

    @direction.setter
    def direction(self, direction):
        """
        Sets the direction of this MessageMediaParticipant.
        The participant's direction.  Values can be: 'inbound' or 'outbound'

        :param direction: The direction of this MessageMediaParticipant.
        :type: str
        """
        allowed_values = ["inbound", "outbound"]
        if direction.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for direction -> " + direction)
            self._direction = "outdated_sdk_version"
        else:
            self._direction = direction

    @property
    def disconnect_type(self):
        """
        Gets the disconnect_type of this MessageMediaParticipant.
        The reason the participant was disconnected from the conversation.

        :return: The disconnect_type of this MessageMediaParticipant.
        :rtype: str
        """
        return self._disconnect_type

    @disconnect_type.setter
    def disconnect_type(self, disconnect_type):
        """
        Sets the disconnect_type of this MessageMediaParticipant.
        The reason the participant was disconnected from the conversation.

        :param disconnect_type: The disconnect_type of this MessageMediaParticipant.
        :type: str
        """
        allowed_values = ["endpoint", "client", "system", "transfer", "transfer.conference", "transfer.consult", "transfer.forward", "transfer.noanswer", "transfer.notavailable", "transport.failure", "error", "peer", "other", "spam"]
        if disconnect_type.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for disconnect_type -> " + disconnect_type)
            self._disconnect_type = "outdated_sdk_version"
        else:
            self._disconnect_type = disconnect_type

    @property
    def held(self):
        """
        Gets the held of this MessageMediaParticipant.
        Value is true when the participant is on hold.

        :return: The held of this MessageMediaParticipant.
        :rtype: bool
        """
        return self._held

    @held.setter
    def held(self, held):
        """
        Sets the held of this MessageMediaParticipant.
        Value is true when the participant is on hold.

        :param held: The held of this MessageMediaParticipant.
        :type: bool
        """
        
        self._held = held

    @property
    def wrapup_required(self):
        """
        Gets the wrapup_required of this MessageMediaParticipant.
        Value is true when the participant requires wrap-up.

        :return: The wrapup_required of this MessageMediaParticipant.
        :rtype: bool
        """
        return self._wrapup_required

    @wrapup_required.setter
    def wrapup_required(self, wrapup_required):
        """
        Sets the wrapup_required of this MessageMediaParticipant.
        Value is true when the participant requires wrap-up.

        :param wrapup_required: The wrapup_required of this MessageMediaParticipant.
        :type: bool
        """
        
        self._wrapup_required = wrapup_required

    @property
    def wrapup_prompt(self):
        """
        Gets the wrapup_prompt of this MessageMediaParticipant.
        The wrap-up prompt indicating the type of wrap-up to be performed.

        :return: The wrapup_prompt of this MessageMediaParticipant.
        :rtype: str
        """
        return self._wrapup_prompt

    @wrapup_prompt.setter
    def wrapup_prompt(self, wrapup_prompt):
        """
        Sets the wrapup_prompt of this MessageMediaParticipant.
        The wrap-up prompt indicating the type of wrap-up to be performed.

        :param wrapup_prompt: The wrapup_prompt of this MessageMediaParticipant.
        :type: str
        """
        
        self._wrapup_prompt = wrapup_prompt

    @property
    def user(self):
        """
        Gets the user of this MessageMediaParticipant.
        The PureCloud user for this participant.

        :return: The user of this MessageMediaParticipant.
        :rtype: DomainEntityRef
        """
        return self._user

    @user.setter
    def user(self, user):
        """
        Sets the user of this MessageMediaParticipant.
        The PureCloud user for this participant.

        :param user: The user of this MessageMediaParticipant.
        :type: DomainEntityRef
        """
        
        self._user = user

    @property
    def queue(self):
        """
        Gets the queue of this MessageMediaParticipant.
        The PureCloud queue for this participant.

        :return: The queue of this MessageMediaParticipant.
        :rtype: DomainEntityRef
        """
        return self._queue

    @queue.setter
    def queue(self, queue):
        """
        Sets the queue of this MessageMediaParticipant.
        The PureCloud queue for this participant.

        :param queue: The queue of this MessageMediaParticipant.
        :type: DomainEntityRef
        """
        
        self._queue = queue

    @property
    def team(self):
        """
        Gets the team of this MessageMediaParticipant.
        The PureCloud team for this participant.

        :return: The team of this MessageMediaParticipant.
        :rtype: DomainEntityRef
        """
        return self._team

    @team.setter
    def team(self, team):
        """
        Sets the team of this MessageMediaParticipant.
        The PureCloud team for this participant.

        :param team: The team of this MessageMediaParticipant.
        :type: DomainEntityRef
        """
        
        self._team = team

    @property
    def attributes(self):
        """
        Gets the attributes of this MessageMediaParticipant.
        A list of ad-hoc attributes for the participant.

        :return: The attributes of this MessageMediaParticipant.
        :rtype: dict(str, str)
        """
        return self._attributes

    @attributes.setter
    def attributes(self, attributes):
        """
        Sets the attributes of this MessageMediaParticipant.
        A list of ad-hoc attributes for the participant.

        :param attributes: The attributes of this MessageMediaParticipant.
        :type: dict(str, str)
        """
        
        self._attributes = attributes

    @property
    def error_info(self):
        """
        Gets the error_info of this MessageMediaParticipant.
        If the conversation ends in error, contains additional error details.

        :return: The error_info of this MessageMediaParticipant.
        :rtype: ErrorInfo
        """
        return self._error_info

    @error_info.setter
    def error_info(self, error_info):
        """
        Sets the error_info of this MessageMediaParticipant.
        If the conversation ends in error, contains additional error details.

        :param error_info: The error_info of this MessageMediaParticipant.
        :type: ErrorInfo
        """
        
        self._error_info = error_info

    @property
    def script(self):
        """
        Gets the script of this MessageMediaParticipant.
        The Engage script that should be used by this participant.

        :return: The script of this MessageMediaParticipant.
        :rtype: DomainEntityRef
        """
        return self._script

    @script.setter
    def script(self, script):
        """
        Sets the script of this MessageMediaParticipant.
        The Engage script that should be used by this participant.

        :param script: The script of this MessageMediaParticipant.
        :type: DomainEntityRef
        """
        
        self._script = script

    @property
    def wrapup_timeout_ms(self):
        """
        Gets the wrapup_timeout_ms of this MessageMediaParticipant.
        The amount of time the participant has to complete wrap-up.

        :return: The wrapup_timeout_ms of this MessageMediaParticipant.
        :rtype: int
        """
        return self._wrapup_timeout_ms

    @wrapup_timeout_ms.setter
    def wrapup_timeout_ms(self, wrapup_timeout_ms):
        """
        Sets the wrapup_timeout_ms of this MessageMediaParticipant.
        The amount of time the participant has to complete wrap-up.

        :param wrapup_timeout_ms: The wrapup_timeout_ms of this MessageMediaParticipant.
        :type: int
        """
        
        self._wrapup_timeout_ms = wrapup_timeout_ms

    @property
    def wrapup_skipped(self):
        """
        Gets the wrapup_skipped of this MessageMediaParticipant.
        Value is true when the participant has skipped wrap-up.

        :return: The wrapup_skipped of this MessageMediaParticipant.
        :rtype: bool
        """
        return self._wrapup_skipped

    @wrapup_skipped.setter
    def wrapup_skipped(self, wrapup_skipped):
        """
        Sets the wrapup_skipped of this MessageMediaParticipant.
        Value is true when the participant has skipped wrap-up.

        :param wrapup_skipped: The wrapup_skipped of this MessageMediaParticipant.
        :type: bool
        """
        
        self._wrapup_skipped = wrapup_skipped

    @property
    def alerting_timeout_ms(self):
        """
        Gets the alerting_timeout_ms of this MessageMediaParticipant.
        Specifies how long the agent has to answer an interaction before being marked as not responding.

        :return: The alerting_timeout_ms of this MessageMediaParticipant.
        :rtype: int
        """
        return self._alerting_timeout_ms

    @alerting_timeout_ms.setter
    def alerting_timeout_ms(self, alerting_timeout_ms):
        """
        Sets the alerting_timeout_ms of this MessageMediaParticipant.
        Specifies how long the agent has to answer an interaction before being marked as not responding.

        :param alerting_timeout_ms: The alerting_timeout_ms of this MessageMediaParticipant.
        :type: int
        """
        
        self._alerting_timeout_ms = alerting_timeout_ms

    @property
    def provider(self):
        """
        Gets the provider of this MessageMediaParticipant.
        The source provider for the communication.

        :return: The provider of this MessageMediaParticipant.
        :rtype: str
        """
        return self._provider

    @provider.setter
    def provider(self, provider):
        """
        Sets the provider of this MessageMediaParticipant.
        The source provider for the communication.

        :param provider: The provider of this MessageMediaParticipant.
        :type: str
        """
        
        self._provider = provider

    @property
    def external_contact(self):
        """
        Gets the external_contact of this MessageMediaParticipant.
        If this participant represents an external contact, then this will be the reference for the external contact.

        :return: The external_contact of this MessageMediaParticipant.
        :rtype: DomainEntityRef
        """
        return self._external_contact

    @external_contact.setter
    def external_contact(self, external_contact):
        """
        Sets the external_contact of this MessageMediaParticipant.
        If this participant represents an external contact, then this will be the reference for the external contact.

        :param external_contact: The external_contact of this MessageMediaParticipant.
        :type: DomainEntityRef
        """
        
        self._external_contact = external_contact

    @property
    def external_organization(self):
        """
        Gets the external_organization of this MessageMediaParticipant.
        If this participant represents an external org, then this will be the reference for the external org.

        :return: The external_organization of this MessageMediaParticipant.
        :rtype: DomainEntityRef
        """
        return self._external_organization

    @external_organization.setter
    def external_organization(self, external_organization):
        """
        Sets the external_organization of this MessageMediaParticipant.
        If this participant represents an external org, then this will be the reference for the external org.

        :param external_organization: The external_organization of this MessageMediaParticipant.
        :type: DomainEntityRef
        """
        
        self._external_organization = external_organization

    @property
    def wrapup(self):
        """
        Gets the wrapup of this MessageMediaParticipant.
        Wrapup for this participant, if it has been applied.

        :return: The wrapup of this MessageMediaParticipant.
        :rtype: Wrapup
        """
        return self._wrapup

    @wrapup.setter
    def wrapup(self, wrapup):
        """
        Sets the wrapup of this MessageMediaParticipant.
        Wrapup for this participant, if it has been applied.

        :param wrapup: The wrapup of this MessageMediaParticipant.
        :type: Wrapup
        """
        
        self._wrapup = wrapup

    @property
    def peer(self):
        """
        Gets the peer of this MessageMediaParticipant.
        The peer communication corresponding to a matching leg for this communication.

        :return: The peer of this MessageMediaParticipant.
        :rtype: str
        """
        return self._peer

    @peer.setter
    def peer(self, peer):
        """
        Sets the peer of this MessageMediaParticipant.
        The peer communication corresponding to a matching leg for this communication.

        :param peer: The peer of this MessageMediaParticipant.
        :type: str
        """
        
        self._peer = peer

    @property
    def flagged_reason(self):
        """
        Gets the flagged_reason of this MessageMediaParticipant.
        The reason specifying why participant flagged the conversation.

        :return: The flagged_reason of this MessageMediaParticipant.
        :rtype: str
        """
        return self._flagged_reason

    @flagged_reason.setter
    def flagged_reason(self, flagged_reason):
        """
        Sets the flagged_reason of this MessageMediaParticipant.
        The reason specifying why participant flagged the conversation.

        :param flagged_reason: The flagged_reason of this MessageMediaParticipant.
        :type: str
        """
        allowed_values = ["general"]
        if flagged_reason.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for flagged_reason -> " + flagged_reason)
            self._flagged_reason = "outdated_sdk_version"
        else:
            self._flagged_reason = flagged_reason

    @property
    def journey_context(self):
        """
        Gets the journey_context of this MessageMediaParticipant.
        Journey System data/context that is applicable to this communication.  When used for historical purposes, the context should be immutable.  When null, there is no applicable Journey System context.

        :return: The journey_context of this MessageMediaParticipant.
        :rtype: JourneyContext
        """
        return self._journey_context

    @journey_context.setter
    def journey_context(self, journey_context):
        """
        Sets the journey_context of this MessageMediaParticipant.
        Journey System data/context that is applicable to this communication.  When used for historical purposes, the context should be immutable.  When null, there is no applicable Journey System context.

        :param journey_context: The journey_context of this MessageMediaParticipant.
        :type: JourneyContext
        """
        
        self._journey_context = journey_context

    @property
    def conversation_routing_data(self):
        """
        Gets the conversation_routing_data of this MessageMediaParticipant.
        Information on how a communication should be routed to an agent.

        :return: The conversation_routing_data of this MessageMediaParticipant.
        :rtype: ConversationRoutingData
        """
        return self._conversation_routing_data

    @conversation_routing_data.setter
    def conversation_routing_data(self, conversation_routing_data):
        """
        Sets the conversation_routing_data of this MessageMediaParticipant.
        Information on how a communication should be routed to an agent.

        :param conversation_routing_data: The conversation_routing_data of this MessageMediaParticipant.
        :type: ConversationRoutingData
        """
        
        self._conversation_routing_data = conversation_routing_data

    @property
    def start_acw_time(self):
        """
        Gets the start_acw_time of this MessageMediaParticipant.
        The timestamp when this participant started after-call work. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The start_acw_time of this MessageMediaParticipant.
        :rtype: datetime
        """
        return self._start_acw_time

    @start_acw_time.setter
    def start_acw_time(self, start_acw_time):
        """
        Sets the start_acw_time of this MessageMediaParticipant.
        The timestamp when this participant started after-call work. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param start_acw_time: The start_acw_time of this MessageMediaParticipant.
        :type: datetime
        """
        
        self._start_acw_time = start_acw_time

    @property
    def end_acw_time(self):
        """
        Gets the end_acw_time of this MessageMediaParticipant.
        The timestamp when this participant ended after-call work. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The end_acw_time of this MessageMediaParticipant.
        :rtype: datetime
        """
        return self._end_acw_time

    @end_acw_time.setter
    def end_acw_time(self, end_acw_time):
        """
        Sets the end_acw_time of this MessageMediaParticipant.
        The timestamp when this participant ended after-call work. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param end_acw_time: The end_acw_time of this MessageMediaParticipant.
        :type: datetime
        """
        
        self._end_acw_time = end_acw_time

    @property
    def to_address(self):
        """
        Gets the to_address of this MessageMediaParticipant.
        Address for the participant on receiving side of the message conversation. If the address is a phone number, E.164 format is recommended.

        :return: The to_address of this MessageMediaParticipant.
        :rtype: Address
        """
        return self._to_address

    @to_address.setter
    def to_address(self, to_address):
        """
        Sets the to_address of this MessageMediaParticipant.
        Address for the participant on receiving side of the message conversation. If the address is a phone number, E.164 format is recommended.

        :param to_address: The to_address of this MessageMediaParticipant.
        :type: Address
        """
        
        self._to_address = to_address

    @property
    def from_address(self):
        """
        Gets the from_address of this MessageMediaParticipant.
        Address for the participant on the sending side of the message conversation. If the address is a phone number, E.164 format is recommended.

        :return: The from_address of this MessageMediaParticipant.
        :rtype: Address
        """
        return self._from_address

    @from_address.setter
    def from_address(self, from_address):
        """
        Sets the from_address of this MessageMediaParticipant.
        Address for the participant on the sending side of the message conversation. If the address is a phone number, E.164 format is recommended.

        :param from_address: The from_address of this MessageMediaParticipant.
        :type: Address
        """
        
        self._from_address = from_address

    @property
    def messages(self):
        """
        Gets the messages of this MessageMediaParticipant.
        Message instance details on the communication.

        :return: The messages of this MessageMediaParticipant.
        :rtype: list[MessageDetails]
        """
        return self._messages

    @messages.setter
    def messages(self, messages):
        """
        Sets the messages of this MessageMediaParticipant.
        Message instance details on the communication.

        :param messages: The messages of this MessageMediaParticipant.
        :type: list[MessageDetails]
        """
        
        self._messages = messages

    @property
    def type(self):
        """
        Gets the type of this MessageMediaParticipant.
        Indicates the type of message platform from which the message originated.

        :return: The type of this MessageMediaParticipant.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this MessageMediaParticipant.
        Indicates the type of message platform from which the message originated.

        :param type: The type of this MessageMediaParticipant.
        :type: str
        """
        allowed_values = ["unknown", "sms", "twitter", "facebook", "line", "whatsapp", "telegram", "kakao", "webmessaging"]
        if type.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for type -> " + type)
            self._type = "outdated_sdk_version"
        else:
            self._type = type

    @property
    def recipient_country(self):
        """
        Gets the recipient_country of this MessageMediaParticipant.
        Indicates the country where the recipient is associated in ISO 3166-1 alpha-2 format.

        :return: The recipient_country of this MessageMediaParticipant.
        :rtype: str
        """
        return self._recipient_country

    @recipient_country.setter
    def recipient_country(self, recipient_country):
        """
        Sets the recipient_country of this MessageMediaParticipant.
        Indicates the country where the recipient is associated in ISO 3166-1 alpha-2 format.

        :param recipient_country: The recipient_country of this MessageMediaParticipant.
        :type: str
        """
        
        self._recipient_country = recipient_country

    @property
    def recipient_type(self):
        """
        Gets the recipient_type of this MessageMediaParticipant.
        The type of the recipient. Eg: Provisioned phoneNumber is the recipient for sms message type.

        :return: The recipient_type of this MessageMediaParticipant.
        :rtype: str
        """
        return self._recipient_type

    @recipient_type.setter
    def recipient_type(self, recipient_type):
        """
        Sets the recipient_type of this MessageMediaParticipant.
        The type of the recipient. Eg: Provisioned phoneNumber is the recipient for sms message type.

        :param recipient_type: The recipient_type of this MessageMediaParticipant.
        :type: str
        """
        
        self._recipient_type = recipient_type

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class DialerContactlistfilterConfigChangeRange(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        DialerContactlistfilterConfigChangeRange - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'min': 'str',
            'max': 'str',
            'min_inclusive': 'bool',
            'max_inclusive': 'bool',
            'in_set': 'list[str]',
            'additional_properties': 'object'
        }

        self.attribute_map = {
            'min': 'min',
            'max': 'max',
            'min_inclusive': 'minInclusive',
            'max_inclusive': 'maxInclusive',
            'in_set': 'inSet',
            'additional_properties': 'additionalProperties'
        }

        self._min = None
        self._max = None
        self._min_inclusive = None
        self._max_inclusive = None
        self._in_set = None
        self._additional_properties = None

    @property
    def min(self):
        """
        Gets the min of this DialerContactlistfilterConfigChangeRange.


        :return: The min of this DialerContactlistfilterConfigChangeRange.
        :rtype: str
        """
        return self._min

    @min.setter
    def min(self, min):
        """
        Sets the min of this DialerContactlistfilterConfigChangeRange.


        :param min: The min of this DialerContactlistfilterConfigChangeRange.
        :type: str
        """
        
        self._min = min

    @property
    def max(self):
        """
        Gets the max of this DialerContactlistfilterConfigChangeRange.


        :return: The max of this DialerContactlistfilterConfigChangeRange.
        :rtype: str
        """
        return self._max

    @max.setter
    def max(self, max):
        """
        Sets the max of this DialerContactlistfilterConfigChangeRange.


        :param max: The max of this DialerContactlistfilterConfigChangeRange.
        :type: str
        """
        
        self._max = max

    @property
    def min_inclusive(self):
        """
        Gets the min_inclusive of this DialerContactlistfilterConfigChangeRange.


        :return: The min_inclusive of this DialerContactlistfilterConfigChangeRange.
        :rtype: bool
        """
        return self._min_inclusive

    @min_inclusive.setter
    def min_inclusive(self, min_inclusive):
        """
        Sets the min_inclusive of this DialerContactlistfilterConfigChangeRange.


        :param min_inclusive: The min_inclusive of this DialerContactlistfilterConfigChangeRange.
        :type: bool
        """
        
        self._min_inclusive = min_inclusive

    @property
    def max_inclusive(self):
        """
        Gets the max_inclusive of this DialerContactlistfilterConfigChangeRange.


        :return: The max_inclusive of this DialerContactlistfilterConfigChangeRange.
        :rtype: bool
        """
        return self._max_inclusive

    @max_inclusive.setter
    def max_inclusive(self, max_inclusive):
        """
        Sets the max_inclusive of this DialerContactlistfilterConfigChangeRange.


        :param max_inclusive: The max_inclusive of this DialerContactlistfilterConfigChangeRange.
        :type: bool
        """
        
        self._max_inclusive = max_inclusive

    @property
    def in_set(self):
        """
        Gets the in_set of this DialerContactlistfilterConfigChangeRange.


        :return: The in_set of this DialerContactlistfilterConfigChangeRange.
        :rtype: list[str]
        """
        return self._in_set

    @in_set.setter
    def in_set(self, in_set):
        """
        Sets the in_set of this DialerContactlistfilterConfigChangeRange.


        :param in_set: The in_set of this DialerContactlistfilterConfigChangeRange.
        :type: list[str]
        """
        
        self._in_set = in_set

    @property
    def additional_properties(self):
        """
        Gets the additional_properties of this DialerContactlistfilterConfigChangeRange.


        :return: The additional_properties of this DialerContactlistfilterConfigChangeRange.
        :rtype: object
        """
        return self._additional_properties

    @additional_properties.setter
    def additional_properties(self, additional_properties):
        """
        Sets the additional_properties of this DialerContactlistfilterConfigChangeRange.


        :param additional_properties: The additional_properties of this DialerContactlistfilterConfigChangeRange.
        :type: object
        """
        
        self._additional_properties = additional_properties

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class ShiftTradeResponse(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        ShiftTradeResponse - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'week_date': 'date',
            'schedule': 'BuScheduleReferenceForMuRoute',
            'state': 'str',
            'initiating_user': 'UserReference',
            'initiating_shift_id': 'str',
            'initiating_shift_start': 'datetime',
            'initiating_shift_end': 'datetime',
            'receiving_user': 'UserReference',
            'receiving_shift_id': 'str',
            'receiving_shift_start': 'datetime',
            'receiving_shift_end': 'datetime',
            'expiration': 'datetime',
            'one_sided': 'bool',
            'acceptable_intervals': 'list[str]',
            'reviewed_by': 'UserReference',
            'reviewed_date': 'datetime',
            'metadata': 'WfmVersionedEntityMetadata'
        }

        self.attribute_map = {
            'id': 'id',
            'week_date': 'weekDate',
            'schedule': 'schedule',
            'state': 'state',
            'initiating_user': 'initiatingUser',
            'initiating_shift_id': 'initiatingShiftId',
            'initiating_shift_start': 'initiatingShiftStart',
            'initiating_shift_end': 'initiatingShiftEnd',
            'receiving_user': 'receivingUser',
            'receiving_shift_id': 'receivingShiftId',
            'receiving_shift_start': 'receivingShiftStart',
            'receiving_shift_end': 'receivingShiftEnd',
            'expiration': 'expiration',
            'one_sided': 'oneSided',
            'acceptable_intervals': 'acceptableIntervals',
            'reviewed_by': 'reviewedBy',
            'reviewed_date': 'reviewedDate',
            'metadata': 'metadata'
        }

        self._id = None
        self._week_date = None
        self._schedule = None
        self._state = None
        self._initiating_user = None
        self._initiating_shift_id = None
        self._initiating_shift_start = None
        self._initiating_shift_end = None
        self._receiving_user = None
        self._receiving_shift_id = None
        self._receiving_shift_start = None
        self._receiving_shift_end = None
        self._expiration = None
        self._one_sided = None
        self._acceptable_intervals = None
        self._reviewed_by = None
        self._reviewed_date = None
        self._metadata = None

    @property
    def id(self):
        """
        Gets the id of this ShiftTradeResponse.
        The ID of this shift trade

        :return: The id of this ShiftTradeResponse.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this ShiftTradeResponse.
        The ID of this shift trade

        :param id: The id of this ShiftTradeResponse.
        :type: str
        """
        
        self._id = id

    @property
    def week_date(self):
        """
        Gets the week_date of this ShiftTradeResponse.
        The start week date of the associated schedule in yyyy-MM-dd format. Dates are represented as an ISO-8601 string. For example: yyyy-MM-dd

        :return: The week_date of this ShiftTradeResponse.
        :rtype: date
        """
        return self._week_date

    @week_date.setter
    def week_date(self, week_date):
        """
        Sets the week_date of this ShiftTradeResponse.
        The start week date of the associated schedule in yyyy-MM-dd format. Dates are represented as an ISO-8601 string. For example: yyyy-MM-dd

        :param week_date: The week_date of this ShiftTradeResponse.
        :type: date
        """
        
        self._week_date = week_date

    @property
    def schedule(self):
        """
        Gets the schedule of this ShiftTradeResponse.
        A reference to the associated schedule

        :return: The schedule of this ShiftTradeResponse.
        :rtype: BuScheduleReferenceForMuRoute
        """
        return self._schedule

    @schedule.setter
    def schedule(self, schedule):
        """
        Sets the schedule of this ShiftTradeResponse.
        A reference to the associated schedule

        :param schedule: The schedule of this ShiftTradeResponse.
        :type: BuScheduleReferenceForMuRoute
        """
        
        self._schedule = schedule

    @property
    def state(self):
        """
        Gets the state of this ShiftTradeResponse.
        The state of this shift trade

        :return: The state of this ShiftTradeResponse.
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """
        Sets the state of this ShiftTradeResponse.
        The state of this shift trade

        :param state: The state of this ShiftTradeResponse.
        :type: str
        """
        allowed_values = ["Unmatched", "Matched", "Approved", "Denied", "Expired", "Canceled"]
        if state.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for state -> " + state)
            self._state = "outdated_sdk_version"
        else:
            self._state = state

    @property
    def initiating_user(self):
        """
        Gets the initiating_user of this ShiftTradeResponse.
        The user who initiated this trade

        :return: The initiating_user of this ShiftTradeResponse.
        :rtype: UserReference
        """
        return self._initiating_user

    @initiating_user.setter
    def initiating_user(self, initiating_user):
        """
        Sets the initiating_user of this ShiftTradeResponse.
        The user who initiated this trade

        :param initiating_user: The initiating_user of this ShiftTradeResponse.
        :type: UserReference
        """
        
        self._initiating_user = initiating_user

    @property
    def initiating_shift_id(self):
        """
        Gets the initiating_shift_id of this ShiftTradeResponse.
        The ID of the shift offered for trade by the initiating user

        :return: The initiating_shift_id of this ShiftTradeResponse.
        :rtype: str
        """
        return self._initiating_shift_id

    @initiating_shift_id.setter
    def initiating_shift_id(self, initiating_shift_id):
        """
        Sets the initiating_shift_id of this ShiftTradeResponse.
        The ID of the shift offered for trade by the initiating user

        :param initiating_shift_id: The initiating_shift_id of this ShiftTradeResponse.
        :type: str
        """
        
        self._initiating_shift_id = initiating_shift_id

    @property
    def initiating_shift_start(self):
        """
        Gets the initiating_shift_start of this ShiftTradeResponse.
        The start date/time of the shift being offered for trade. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The initiating_shift_start of this ShiftTradeResponse.
        :rtype: datetime
        """
        return self._initiating_shift_start

    @initiating_shift_start.setter
    def initiating_shift_start(self, initiating_shift_start):
        """
        Sets the initiating_shift_start of this ShiftTradeResponse.
        The start date/time of the shift being offered for trade. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param initiating_shift_start: The initiating_shift_start of this ShiftTradeResponse.
        :type: datetime
        """
        
        self._initiating_shift_start = initiating_shift_start

    @property
    def initiating_shift_end(self):
        """
        Gets the initiating_shift_end of this ShiftTradeResponse.
        The end date/time of the shift being offered for trade. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The initiating_shift_end of this ShiftTradeResponse.
        :rtype: datetime
        """
        return self._initiating_shift_end

    @initiating_shift_end.setter
    def initiating_shift_end(self, initiating_shift_end):
        """
        Sets the initiating_shift_end of this ShiftTradeResponse.
        The end date/time of the shift being offered for trade. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param initiating_shift_end: The initiating_shift_end of this ShiftTradeResponse.
        :type: datetime
        """
        
        self._initiating_shift_end = initiating_shift_end

    @property
    def receiving_user(self):
        """
        Gets the receiving_user of this ShiftTradeResponse.
        The user matching the trade, or if the state is not Matched, the user to whom the trade request was sent

        :return: The receiving_user of this ShiftTradeResponse.
        :rtype: UserReference
        """
        return self._receiving_user

    @receiving_user.setter
    def receiving_user(self, receiving_user):
        """
        Sets the receiving_user of this ShiftTradeResponse.
        The user matching the trade, or if the state is not Matched, the user to whom the trade request was sent

        :param receiving_user: The receiving_user of this ShiftTradeResponse.
        :type: UserReference
        """
        
        self._receiving_user = receiving_user

    @property
    def receiving_shift_id(self):
        """
        Gets the receiving_shift_id of this ShiftTradeResponse.
        The ID of the shift being exchanged for the initiating shift, null if the receiving user is picking up a shift

        :return: The receiving_shift_id of this ShiftTradeResponse.
        :rtype: str
        """
        return self._receiving_shift_id

    @receiving_shift_id.setter
    def receiving_shift_id(self, receiving_shift_id):
        """
        Sets the receiving_shift_id of this ShiftTradeResponse.
        The ID of the shift being exchanged for the initiating shift, null if the receiving user is picking up a shift

        :param receiving_shift_id: The receiving_shift_id of this ShiftTradeResponse.
        :type: str
        """
        
        self._receiving_shift_id = receiving_shift_id

    @property
    def receiving_shift_start(self):
        """
        Gets the receiving_shift_start of this ShiftTradeResponse.
        The start date/time of the receiving shift. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The receiving_shift_start of this ShiftTradeResponse.
        :rtype: datetime
        """
        return self._receiving_shift_start

    @receiving_shift_start.setter
    def receiving_shift_start(self, receiving_shift_start):
        """
        Sets the receiving_shift_start of this ShiftTradeResponse.
        The start date/time of the receiving shift. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param receiving_shift_start: The receiving_shift_start of this ShiftTradeResponse.
        :type: datetime
        """
        
        self._receiving_shift_start = receiving_shift_start

    @property
    def receiving_shift_end(self):
        """
        Gets the receiving_shift_end of this ShiftTradeResponse.
        The end date/time of the receiving shift. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The receiving_shift_end of this ShiftTradeResponse.
        :rtype: datetime
        """
        return self._receiving_shift_end

    @receiving_shift_end.setter
    def receiving_shift_end(self, receiving_shift_end):
        """
        Sets the receiving_shift_end of this ShiftTradeResponse.
        The end date/time of the receiving shift. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param receiving_shift_end: The receiving_shift_end of this ShiftTradeResponse.
        :type: datetime
        """
        
        self._receiving_shift_end = receiving_shift_end

    @property
    def expiration(self):
        """
        Gets the expiration of this ShiftTradeResponse.
        When this shift trade offer will expire if not matched or approved. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The expiration of this ShiftTradeResponse.
        :rtype: datetime
        """
        return self._expiration

    @expiration.setter
    def expiration(self, expiration):
        """
        Sets the expiration of this ShiftTradeResponse.
        When this shift trade offer will expire if not matched or approved. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param expiration: The expiration of this ShiftTradeResponse.
        :type: datetime
        """
        
        self._expiration = expiration

    @property
    def one_sided(self):
        """
        Gets the one_sided of this ShiftTradeResponse.
        Whether this is a one-sided shift trade (e.g. the initiating user is not asking for a shift in return)

        :return: The one_sided of this ShiftTradeResponse.
        :rtype: bool
        """
        return self._one_sided

    @one_sided.setter
    def one_sided(self, one_sided):
        """
        Sets the one_sided of this ShiftTradeResponse.
        Whether this is a one-sided shift trade (e.g. the initiating user is not asking for a shift in return)

        :param one_sided: The one_sided of this ShiftTradeResponse.
        :type: bool
        """
        
        self._one_sided = one_sided

    @property
    def acceptable_intervals(self):
        """
        Gets the acceptable_intervals of this ShiftTradeResponse.


        :return: The acceptable_intervals of this ShiftTradeResponse.
        :rtype: list[str]
        """
        return self._acceptable_intervals

    @acceptable_intervals.setter
    def acceptable_intervals(self, acceptable_intervals):
        """
        Sets the acceptable_intervals of this ShiftTradeResponse.


        :param acceptable_intervals: The acceptable_intervals of this ShiftTradeResponse.
        :type: list[str]
        """
        
        self._acceptable_intervals = acceptable_intervals

    @property
    def reviewed_by(self):
        """
        Gets the reviewed_by of this ShiftTradeResponse.
        The user who reviewed this shift trade

        :return: The reviewed_by of this ShiftTradeResponse.
        :rtype: UserReference
        """
        return self._reviewed_by

    @reviewed_by.setter
    def reviewed_by(self, reviewed_by):
        """
        Sets the reviewed_by of this ShiftTradeResponse.
        The user who reviewed this shift trade

        :param reviewed_by: The reviewed_by of this ShiftTradeResponse.
        :type: UserReference
        """
        
        self._reviewed_by = reviewed_by

    @property
    def reviewed_date(self):
        """
        Gets the reviewed_date of this ShiftTradeResponse.
        The timestamp when this shift trade was reviewed. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The reviewed_date of this ShiftTradeResponse.
        :rtype: datetime
        """
        return self._reviewed_date

    @reviewed_date.setter
    def reviewed_date(self, reviewed_date):
        """
        Sets the reviewed_date of this ShiftTradeResponse.
        The timestamp when this shift trade was reviewed. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param reviewed_date: The reviewed_date of this ShiftTradeResponse.
        :type: datetime
        """
        
        self._reviewed_date = reviewed_date

    @property
    def metadata(self):
        """
        Gets the metadata of this ShiftTradeResponse.
        Version data for this trade

        :return: The metadata of this ShiftTradeResponse.
        :rtype: WfmVersionedEntityMetadata
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """
        Sets the metadata of this ShiftTradeResponse.
        Version data for this trade

        :param metadata: The metadata of this ShiftTradeResponse.
        :type: WfmVersionedEntityMetadata
        """
        
        self._metadata = metadata

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class WfmUserNotificationTopicWfmUserNotification(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        WfmUserNotificationTopicWfmUserNotification - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'mutable_group_id': 'str',
            'timestamp': 'datetime',
            'type': 'str',
            'shift_trade': 'WfmUserNotificationTopicShiftTradeNotification',
            'time_off_request': 'WfmUserNotificationTopicTimeOffRequestNotification',
            'agent_notification': 'bool',
            'other_notification_ids_in_group': 'list[str]',
            'marked_as_read': 'bool'
        }

        self.attribute_map = {
            'id': 'id',
            'mutable_group_id': 'mutableGroupId',
            'timestamp': 'timestamp',
            'type': 'type',
            'shift_trade': 'shiftTrade',
            'time_off_request': 'timeOffRequest',
            'agent_notification': 'agentNotification',
            'other_notification_ids_in_group': 'otherNotificationIdsInGroup',
            'marked_as_read': 'markedAsRead'
        }

        self._id = None
        self._mutable_group_id = None
        self._timestamp = None
        self._type = None
        self._shift_trade = None
        self._time_off_request = None
        self._agent_notification = None
        self._other_notification_ids_in_group = None
        self._marked_as_read = None

    @property
    def id(self):
        """
        Gets the id of this WfmUserNotificationTopicWfmUserNotification.


        :return: The id of this WfmUserNotificationTopicWfmUserNotification.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this WfmUserNotificationTopicWfmUserNotification.


        :param id: The id of this WfmUserNotificationTopicWfmUserNotification.
        :type: str
        """
        
        self._id = id

    @property
    def mutable_group_id(self):
        """
        Gets the mutable_group_id of this WfmUserNotificationTopicWfmUserNotification.


        :return: The mutable_group_id of this WfmUserNotificationTopicWfmUserNotification.
        :rtype: str
        """
        return self._mutable_group_id

    @mutable_group_id.setter
    def mutable_group_id(self, mutable_group_id):
        """
        Sets the mutable_group_id of this WfmUserNotificationTopicWfmUserNotification.


        :param mutable_group_id: The mutable_group_id of this WfmUserNotificationTopicWfmUserNotification.
        :type: str
        """
        
        self._mutable_group_id = mutable_group_id

    @property
    def timestamp(self):
        """
        Gets the timestamp of this WfmUserNotificationTopicWfmUserNotification.


        :return: The timestamp of this WfmUserNotificationTopicWfmUserNotification.
        :rtype: datetime
        """
        return self._timestamp

    @timestamp.setter
    def timestamp(self, timestamp):
        """
        Sets the timestamp of this WfmUserNotificationTopicWfmUserNotification.


        :param timestamp: The timestamp of this WfmUserNotificationTopicWfmUserNotification.
        :type: datetime
        """
        
        self._timestamp = timestamp

    @property
    def type(self):
        """
        Gets the type of this WfmUserNotificationTopicWfmUserNotification.


        :return: The type of this WfmUserNotificationTopicWfmUserNotification.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this WfmUserNotificationTopicWfmUserNotification.


        :param type: The type of this WfmUserNotificationTopicWfmUserNotification.
        :type: str
        """
        allowed_values = ["ShiftTrade", "TimeOffRequest"]
        if type.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for type -> " + type)
            self._type = "outdated_sdk_version"
        else:
            self._type = type

    @property
    def shift_trade(self):
        """
        Gets the shift_trade of this WfmUserNotificationTopicWfmUserNotification.


        :return: The shift_trade of this WfmUserNotificationTopicWfmUserNotification.
        :rtype: WfmUserNotificationTopicShiftTradeNotification
        """
        return self._shift_trade

    @shift_trade.setter
    def shift_trade(self, shift_trade):
        """
        Sets the shift_trade of this WfmUserNotificationTopicWfmUserNotification.


        :param shift_trade: The shift_trade of this WfmUserNotificationTopicWfmUserNotification.
        :type: WfmUserNotificationTopicShiftTradeNotification
        """
        
        self._shift_trade = shift_trade

    @property
    def time_off_request(self):
        """
        Gets the time_off_request of this WfmUserNotificationTopicWfmUserNotification.


        :return: The time_off_request of this WfmUserNotificationTopicWfmUserNotification.
        :rtype: WfmUserNotificationTopicTimeOffRequestNotification
        """
        return self._time_off_request

    @time_off_request.setter
    def time_off_request(self, time_off_request):
        """
        Sets the time_off_request of this WfmUserNotificationTopicWfmUserNotification.


        :param time_off_request: The time_off_request of this WfmUserNotificationTopicWfmUserNotification.
        :type: WfmUserNotificationTopicTimeOffRequestNotification
        """
        
        self._time_off_request = time_off_request

    @property
    def agent_notification(self):
        """
        Gets the agent_notification of this WfmUserNotificationTopicWfmUserNotification.


        :return: The agent_notification of this WfmUserNotificationTopicWfmUserNotification.
        :rtype: bool
        """
        return self._agent_notification

    @agent_notification.setter
    def agent_notification(self, agent_notification):
        """
        Sets the agent_notification of this WfmUserNotificationTopicWfmUserNotification.


        :param agent_notification: The agent_notification of this WfmUserNotificationTopicWfmUserNotification.
        :type: bool
        """
        
        self._agent_notification = agent_notification

    @property
    def other_notification_ids_in_group(self):
        """
        Gets the other_notification_ids_in_group of this WfmUserNotificationTopicWfmUserNotification.


        :return: The other_notification_ids_in_group of this WfmUserNotificationTopicWfmUserNotification.
        :rtype: list[str]
        """
        return self._other_notification_ids_in_group

    @other_notification_ids_in_group.setter
    def other_notification_ids_in_group(self, other_notification_ids_in_group):
        """
        Sets the other_notification_ids_in_group of this WfmUserNotificationTopicWfmUserNotification.


        :param other_notification_ids_in_group: The other_notification_ids_in_group of this WfmUserNotificationTopicWfmUserNotification.
        :type: list[str]
        """
        
        self._other_notification_ids_in_group = other_notification_ids_in_group

    @property
    def marked_as_read(self):
        """
        Gets the marked_as_read of this WfmUserNotificationTopicWfmUserNotification.


        :return: The marked_as_read of this WfmUserNotificationTopicWfmUserNotification.
        :rtype: bool
        """
        return self._marked_as_read

    @marked_as_read.setter
    def marked_as_read(self, marked_as_read):
        """
        Sets the marked_as_read of this WfmUserNotificationTopicWfmUserNotification.


        :param marked_as_read: The marked_as_read of this WfmUserNotificationTopicWfmUserNotification.
        :type: bool
        """
        
        self._marked_as_read = marked_as_read

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class DialerOutboundSettingsConfigChangeOutboundSettings(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        DialerOutboundSettingsConfigChangeOutboundSettings - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'date_created': 'datetime',
            'date_modified': 'datetime',
            'version': 'int',
            'max_calls_per_agent': 'int',
            'max_line_utilization': 'float',
            'abandon_seconds': 'float',
            'compliance_abandon_rate_denominator': 'str',
            'automatic_time_zone_mapping': 'DialerOutboundSettingsConfigChangeAutomaticTimeZoneMappingSettings'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'date_created': 'dateCreated',
            'date_modified': 'dateModified',
            'version': 'version',
            'max_calls_per_agent': 'maxCallsPerAgent',
            'max_line_utilization': 'maxLineUtilization',
            'abandon_seconds': 'abandonSeconds',
            'compliance_abandon_rate_denominator': 'complianceAbandonRateDenominator',
            'automatic_time_zone_mapping': 'automaticTimeZoneMapping'
        }

        self._id = None
        self._name = None
        self._date_created = None
        self._date_modified = None
        self._version = None
        self._max_calls_per_agent = None
        self._max_line_utilization = None
        self._abandon_seconds = None
        self._compliance_abandon_rate_denominator = None
        self._automatic_time_zone_mapping = None

    @property
    def id(self):
        """
        Gets the id of this DialerOutboundSettingsConfigChangeOutboundSettings.


        :return: The id of this DialerOutboundSettingsConfigChangeOutboundSettings.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this DialerOutboundSettingsConfigChangeOutboundSettings.


        :param id: The id of this DialerOutboundSettingsConfigChangeOutboundSettings.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this DialerOutboundSettingsConfigChangeOutboundSettings.


        :return: The name of this DialerOutboundSettingsConfigChangeOutboundSettings.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this DialerOutboundSettingsConfigChangeOutboundSettings.


        :param name: The name of this DialerOutboundSettingsConfigChangeOutboundSettings.
        :type: str
        """
        
        self._name = name

    @property
    def date_created(self):
        """
        Gets the date_created of this DialerOutboundSettingsConfigChangeOutboundSettings.


        :return: The date_created of this DialerOutboundSettingsConfigChangeOutboundSettings.
        :rtype: datetime
        """
        return self._date_created

    @date_created.setter
    def date_created(self, date_created):
        """
        Sets the date_created of this DialerOutboundSettingsConfigChangeOutboundSettings.


        :param date_created: The date_created of this DialerOutboundSettingsConfigChangeOutboundSettings.
        :type: datetime
        """
        
        self._date_created = date_created

    @property
    def date_modified(self):
        """
        Gets the date_modified of this DialerOutboundSettingsConfigChangeOutboundSettings.


        :return: The date_modified of this DialerOutboundSettingsConfigChangeOutboundSettings.
        :rtype: datetime
        """
        return self._date_modified

    @date_modified.setter
    def date_modified(self, date_modified):
        """
        Sets the date_modified of this DialerOutboundSettingsConfigChangeOutboundSettings.


        :param date_modified: The date_modified of this DialerOutboundSettingsConfigChangeOutboundSettings.
        :type: datetime
        """
        
        self._date_modified = date_modified

    @property
    def version(self):
        """
        Gets the version of this DialerOutboundSettingsConfigChangeOutboundSettings.


        :return: The version of this DialerOutboundSettingsConfigChangeOutboundSettings.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """
        Sets the version of this DialerOutboundSettingsConfigChangeOutboundSettings.


        :param version: The version of this DialerOutboundSettingsConfigChangeOutboundSettings.
        :type: int
        """
        
        self._version = version

    @property
    def max_calls_per_agent(self):
        """
        Gets the max_calls_per_agent of this DialerOutboundSettingsConfigChangeOutboundSettings.


        :return: The max_calls_per_agent of this DialerOutboundSettingsConfigChangeOutboundSettings.
        :rtype: int
        """
        return self._max_calls_per_agent

    @max_calls_per_agent.setter
    def max_calls_per_agent(self, max_calls_per_agent):
        """
        Sets the max_calls_per_agent of this DialerOutboundSettingsConfigChangeOutboundSettings.


        :param max_calls_per_agent: The max_calls_per_agent of this DialerOutboundSettingsConfigChangeOutboundSettings.
        :type: int
        """
        
        self._max_calls_per_agent = max_calls_per_agent

    @property
    def max_line_utilization(self):
        """
        Gets the max_line_utilization of this DialerOutboundSettingsConfigChangeOutboundSettings.


        :return: The max_line_utilization of this DialerOutboundSettingsConfigChangeOutboundSettings.
        :rtype: float
        """
        return self._max_line_utilization

    @max_line_utilization.setter
    def max_line_utilization(self, max_line_utilization):
        """
        Sets the max_line_utilization of this DialerOutboundSettingsConfigChangeOutboundSettings.


        :param max_line_utilization: The max_line_utilization of this DialerOutboundSettingsConfigChangeOutboundSettings.
        :type: float
        """
        
        self._max_line_utilization = max_line_utilization

    @property
    def abandon_seconds(self):
        """
        Gets the abandon_seconds of this DialerOutboundSettingsConfigChangeOutboundSettings.


        :return: The abandon_seconds of this DialerOutboundSettingsConfigChangeOutboundSettings.
        :rtype: float
        """
        return self._abandon_seconds

    @abandon_seconds.setter
    def abandon_seconds(self, abandon_seconds):
        """
        Sets the abandon_seconds of this DialerOutboundSettingsConfigChangeOutboundSettings.


        :param abandon_seconds: The abandon_seconds of this DialerOutboundSettingsConfigChangeOutboundSettings.
        :type: float
        """
        
        self._abandon_seconds = abandon_seconds

    @property
    def compliance_abandon_rate_denominator(self):
        """
        Gets the compliance_abandon_rate_denominator of this DialerOutboundSettingsConfigChangeOutboundSettings.


        :return: The compliance_abandon_rate_denominator of this DialerOutboundSettingsConfigChangeOutboundSettings.
        :rtype: str
        """
        return self._compliance_abandon_rate_denominator

    @compliance_abandon_rate_denominator.setter
    def compliance_abandon_rate_denominator(self, compliance_abandon_rate_denominator):
        """
        Sets the compliance_abandon_rate_denominator of this DialerOutboundSettingsConfigChangeOutboundSettings.


        :param compliance_abandon_rate_denominator: The compliance_abandon_rate_denominator of this DialerOutboundSettingsConfigChangeOutboundSettings.
        :type: str
        """
        allowed_values = ["ALL_CALLS", "CALLS_THAT_REACHED_QUEUE"]
        if compliance_abandon_rate_denominator.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for compliance_abandon_rate_denominator -> " + compliance_abandon_rate_denominator)
            self._compliance_abandon_rate_denominator = "outdated_sdk_version"
        else:
            self._compliance_abandon_rate_denominator = compliance_abandon_rate_denominator

    @property
    def automatic_time_zone_mapping(self):
        """
        Gets the automatic_time_zone_mapping of this DialerOutboundSettingsConfigChangeOutboundSettings.


        :return: The automatic_time_zone_mapping of this DialerOutboundSettingsConfigChangeOutboundSettings.
        :rtype: DialerOutboundSettingsConfigChangeAutomaticTimeZoneMappingSettings
        """
        return self._automatic_time_zone_mapping

    @automatic_time_zone_mapping.setter
    def automatic_time_zone_mapping(self, automatic_time_zone_mapping):
        """
        Sets the automatic_time_zone_mapping of this DialerOutboundSettingsConfigChangeOutboundSettings.


        :param automatic_time_zone_mapping: The automatic_time_zone_mapping of this DialerOutboundSettingsConfigChangeOutboundSettings.
        :type: DialerOutboundSettingsConfigChangeAutomaticTimeZoneMappingSettings
        """
        
        self._automatic_time_zone_mapping = automatic_time_zone_mapping

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other

